@@ -1,7 +1,13 @@
 import inspect
 import typing
 from .base_response import BaseResponse
-from vkbottle_types.objects import FaveBookmark, FavePage, FaveTag, GroupsGroup, UsersUserFull
+from vkbottle_types.objects import (
+    FaveBookmark,
+    FavePage,
+    FaveTag,
+    GroupsGroup,
+    UsersUserFull,
+)
 
 
 class AddTagResponse(BaseResponse):
